%   BGJ_Table1.m
%
%
%   This code does the following:
%       replicates BGJ Table 1 for full in-sample period and two subperiods
%       generates summary stats for out-of-sample Update (and associated subperiods)
%
%   Data are monthly returns to the CRSP "NYSE-only" market indices from WRDS.
%   RF returns are sourced from Ken French's Data Library.
%
%
%   Key takeaways:
%       Can replicate BGJ Table 1 almost perfectly. The only differences are:
%       i)  Subperiod2 rho on VM mkt should be -0.007 (BGJ tabulate +0.07)
%       ii) Subperiod2 rho on excess VW mkt: BGJ report 0.03, I get 0.0028.
%
%   This code generates summary stats for both VW and EW NYSE index.
%   The former is tabulated in our paper; the latter in the appendix.
%
%
%   PG: 28 Nov-2018:    first work
%   PG:  4 Feb-2019:    updated with data thru to Dec-2018
%

%%  Preliminaries

clear;
clc;
tic;


Directory.Data='G:\active\papers\CFR\Accompanying Files\data';
Directory.Programs='G:\active\papers\CFR\Accompanying Files\programs';


%%  Load Data
%
%   "NYSE2018.xlsx" is a spreadhseet containg a WRDS download of 
%   monthly returns as follows:
%       
%       col     YYYYMMDD (not used)
%       col 1   mthnum ranging from 1:1116
%       col 2   YYYY
%       col 3   MM
%       col 4   NYSE-only VW mkt (inc dividend distributions)
%       col 5   NYSE-only VW mkt (ex. div)
%       col 6   NYSE-only EW mkt (inc dividend distributions)
%       col 7   NYSE-only EW mkt (ex. div)
%       col     "totval" (not used)
%       col     "totcnt" (not used)
%       col     "usdval" (not used)
%       col     "usdcnt" (not used)
%
%       col 8   RF from Ken French Data Library
%       col 9   VW-RF   (added below)
%       col 10  EW-RF   (added below)
%
%   Monthly data spans Jan-1926 thru Dec-2018


cd(Directory.Data)

    data=xlsread('NYSE2018.xlsx','b2:h1117');
    RF=xlsread('NYSE2018.xlsx','n2:n1117');
    
cd(Directory.Programs)


%   RF data starts 1926:7, so first 6 cells in spreadsheet are blank.
%   insert NaNs in first 6 rows of RF.
%   These dates are not part of our sample, so not a big deal.

RF=[nan(6,1);RF];


%   add RF into 8th column of "data"
data=[data RF];


%   add excess market returns into columns 9+10
data=[data data(:,4)-data(:,8) data(:,6)-data(:,8)];


data(:,4:end)=data(:,4:end)*100;    % express returns as percentages



%%  Replicate BGJ Table 1 Summary Stats for full in-sample period


%   Full sample spans Apr-1954 (mthnum=340) thru Dec-1986 (mthnum=732)
%   Subperiod1 spans  Apr-1954 (mthnum=340) thru Jul-1970 (mthnum=535)
%   Subperiod2 spans  Aug-1970 (mthnum=536) thru Dec-1986 (mthnum=732)


%   "junk" holds relevant data for full in-sample period
junk=data(340:732,[4 6 8 9 10]);            % VW, EW, RF, VW-RF, EW-RF

rho=nan(5,1);                               % to store estimates of first-order autocorrelations


for i=1:size(junk,2)                        % estimates first-order autocorrelations
    y=junk(2:end,i);
    x=[ones(length(y),1) junk(1:end-1,i)];
    beta=(x'*x)\(x'*y);
    rho(i)=beta(2);
end


output=[mean(junk)' std(junk)' rho];
fprintf('Full In-sample Summary Stats\n\n')
fprintf('\t%2.4f\t%2.4f\t%2.4f\n',output');

output_kurtosis=kurtosis(junk(:,end-1:end),0)-3;
fprintf('\nKurtosis for Monthly Excess Market Returns (VW and EW)\n')
fprintf('\t%2.4f\t%2.4f\n\n',output_kurtosis);


%   displayed to screen:
%           mean    std     rho(1)
%
%   VW
%   EW
%   RF
%   VW-RF
%   EW-RF


%   the above reconciles near-perfectly to BGJ Table 1


%%  Replicate BGJ (1989) First Subperiod: Summary Stats
%
%   Subperiod1 spans  Apr-1954 (mthnum=340) thru Jul-1970 (mthnum=535)


fprintf('\n\nIn-sample Subperiod 1: Summary Stats\n\n')

junk=data(340:535,[4 6 8]);                             %  VW, EW RF
junk=[junk junk(:,1)-junk(:,3) junk(:,2)-junk(:,3)];    % excess returns


%   estimate first-order autocorrelations

rho=nan(5,1);                               % to store estimates of first-order autocorrelations

for i=1:size(junk,2)
    y=junk(2:end,i);
    x=[ones(length(y),1) junk(1:end-1,i)];
    beta=(x'*x)\(x'*y);
    rho(i)=beta(2);
end


output=[mean(junk)' std(junk)' rho];
fprintf('Subperiod 1: Summary Stats\n\n')
fprintf('\t%2.4f\t%2.4f\t%2.4f\n',output');

output_kurtosis=kurtosis(junk(:,end-1:end),0)-3;
fprintf('\nKurtosis for Monthly Excess Market Returns (VW and EW)\n')
fprintf('\t%2.4f\t%2.4f\n\n',output_kurtosis);


%   the above reconciles near-perfectly to BGJ Table 1: subperiod1


%%  Replicate BGJ (1989) Second Subperiod: Summary Stats
%
%   Subperiod2 spans  Aug-1970 (mthnum=536) thru Dec-1986 (mthnum=732)


fprintf('\n\nSubperiod 2: Summary Stats\n\n')

junk=data(536:732,[4 6 8]);                             %  VW, EW RF
junk=[junk junk(:,1)-junk(:,3) junk(:,2)-junk(:,3)];    % excess returns


rho=nan(5,1);

for i=1:size(junk,2)
    y=junk(2:end,i);
    x=[ones(length(y),1) junk(1:end-1,i)];
    beta=(x'*x)\(x'*y);
    rho(i)=beta(2);
end


output=[mean(junk)' std(junk)' rho];
fprintf('Subperiod 2: Summary Stats\n\n')
fprintf('\t%2.4f\t%2.4f\t%2.4f\n',output');

output_kurtosis=kurtosis(junk(:,end-1:end),0)-3;
fprintf('\nKurtosis for Monthly Excess Market Returns\n')
fprintf('\t%2.4f\t%2.4f\n\n',output_kurtosis);


%   the above reconciles near-perfectly to BGJ Table 1: subperiod2


%%  Update Out-of-Sample Summary stats

%   Calculate summary stats for:
%
%   Full update period  spans Jan-1987 (mthnum=733) thru Dec-2018 (mthnum=1116)
%   Update Subperiod1   spans Jan-1987 (mthnum=733) thru Jul-2007 (mthnum=979)
%   Update Subperiod2   spans Aug-2007 (mthnum=980) thru Dec-2018 (mthnum=1116)
%   Combined in-sample + out-sample period spans Apr-1954 (mthnum=340) thru Dec-2018 (mthnum=1116)



fprintf('\n\nUpdate Full Out-of-Sample Period: Summary Stats\n\n')

junk=data(733:1116,[4 6 8]);                            % VW, EW RF
junk=[junk junk(:,1)-junk(:,3) junk(:,2)-junk(:,3)];    % excess returns


rho=nan(5,1);                               % to store first-order autocorrelations

for i=1:size(junk,2)
    y=junk(2:end,i);
    x=[ones(length(y),1) junk(1:end-1,i)];
    beta=(x'*x)\(x'*y);
    rho(i)=beta(2);
end


output=[mean(junk)' std(junk)' rho];
fprintf('Full out-of-sample: Summary Stats\n\n')
fprintf('\t%2.4f\t%2.4f\t%2.4f\n',output');

output_kurtosis=kurtosis(junk(:,end-1:end),0)-3;
fprintf('\nKurtosis for Monthly Excess Market Returns\n')
fprintf('\t%2.4f\t%2.4f\n\n',output_kurtosis);



%   ----------------------------------------------------------------------
fprintf('\n\nUpdate Subperiod 1: Summary Stats\n\n')

junk=data(733:924,[4 6 8]);                             %  VW, EW RF  v1 equal subperiods
junk=data(733:979,[4 6 8]);                             %  VW, EW RF
junk=[junk junk(:,1)-junk(:,3) junk(:,2)-junk(:,3)];    % excess returns


rho=nan(5,1);                               % to store first-order autocorrelations

for i=1:size(junk,2)
    y=junk(2:end,i);
    x=[ones(length(y),1) junk(1:end-1,i)];
    beta=(x'*x)\(x'*y);
    rho(i)=beta(2);
end


output=[mean(junk)' std(junk)' rho];
fprintf('Update Subperiod1: Summary Stats\n\n')
fprintf('\t%2.4f\t%2.4f\t%2.4f\n',output');

output_kurtosis=kurtosis(junk(:,end-1:end),0)-3;
fprintf('\nKurtosis for Monthly Excess Market Returns\n')
fprintf('\t%2.4f\t%2.4f\n\n',output_kurtosis);


%   ----------------------------------------------------------------------
fprintf('\n\nUpdate Subperiod 2: Summary Stats\n\n')

junk=data(925:1116,[4 6 8]);                             %  VW, EW RF
junk=data(980:1116,[4 6 8]);                             %  VW, EW RF
junk=[junk junk(:,1)-junk(:,3) junk(:,2)-junk(:,3)];    % excess returns


rho=nan(5,1);                               % to store first-order autocorrelations

for i=1:size(junk,2)
    y=junk(2:end,i);
    x=[ones(length(y),1) junk(1:end-1,i)];
    beta=(x'*x)\(x'*y);
    rho(i)=beta(2);
end


output=[mean(junk)' std(junk)' rho];
fprintf('Update Subperiod2: Summary Stats\n\n')
fprintf('\t%2.4f\t%2.4f\t%2.4f\n',output');

output_kurtosis=kurtosis(junk(:,end-1:end),0)-3;
fprintf('\nKurtosis for Monthly Excess Market Returns\n')
fprintf('\t%2.4f\t%2.4f\n\n',output_kurtosis);


%   ----------------------------------------------------------------------
fprintf('\n\nUpdate Combined In-Sample + Out-Sample Period: Summary Stats\n\n')

junk=data(340:1116,[4 6 8]);                             %  VW, EW RF
junk=[junk junk(:,1)-junk(:,3) junk(:,2)-junk(:,3)];    % excess returns


rho=nan(5,1);                               % to store first-order autocorrelations

for i=1:size(junk,2)
    y=junk(2:end,i);
    x=[ones(length(y),1) junk(1:end-1,i)];
    beta=(x'*x)\(x'*y);
    rho(i)=beta(2);
end


output=[mean(junk)' std(junk)' rho];
fprintf('Fill out-of-sample: Summary Stats\n\n')
fprintf('\t%2.4f\t%2.4f\t%2.4f\n',output');

output_kurtosis=kurtosis(junk(:,end-1:end),0)-3;
fprintf('\nKurtosis for Monthly Excess Market Returns\n')
fprintf('\t%2.4f\t%2.4f\n\n',output_kurtosis);


%%  Save Key Data as "data,mat"
%
%   subsequent m-files load data.mat


save data.mat data

%   "data" is 1116x10 double array
%   Monthly data spanning Jan-1926 thru Dec-2018
%
%       col 1   mthnum ranging from 1:1116
%       col 2   YYYY
%       col 3   MM
%       col 4   VW mkt (inc dividend distributions)
%       col 5   VW mkt (ex. div)
%       col 6   EW mkt (inc dividend distributions)
%       col 7   EW mkt (ex. div)
%       col 8   RF (spliced in below)
%       col 9   VW-RF
%       col 10  EW-RF


%%  Tidy Up


clear beta i RF  x y junk rho output_kurtosis output















