%   BGJ_Table2.m
%
%   Replicate BGJ Table 2:
%       recursively estimate predictive model
%       signal from predictive model drives trading strategy
%       compile returns to BGJ's "managed portfolio"
%
%
%   Data are monthly returns to the CRSP "NYSE-only" market indices from WRDS.
%   RF returns are sourced from Ken French's Data Library.
%
%
%   PG: 29 Nov-2018
%   PG:  4 Feb-2019:    updated with data thru to Dec-2018


%%  Preliminaries

clear;
clc;
tic;

global data                 % "data" array used in subroutine


Directory.Data='G:\active\papers\CFR\Accompanying Files\data';
Directory.Programs='G:\active\papers\CFR\Accompanying Files\programs';


%%  Load Data
%
%   Either load data from NYSE2018.xlsx, OR
%   if "BGJ_Table1.m" has been run, the data will already reside in a mat-file.
%
%
%   "NYSE2018.xlsx" is a spreadhseet containg a WRDS download of 
%   monthly returns as follows:
%       
%       col     YYYYMMDD (not used)
%       col 1   mthnum ranging from 1:1116
%       col 2   YYYY
%       col 3   MM
%       col 4   NYSE-only VW mkt (inc dividend distributions)
%       col 5   NYSE-only VW mkt (ex. div)
%       col 6   NYSE-only EW mkt (inc dividend distributions)
%       col 7   NYSE-only EW mkt (ex. div)
%       col     "totval" (not used)
%       col     "totcnt" (not used)
%       col     "usdval" (not used)
%       col     "usdcnt" (not used)
%
%       col 8   RF from Ken French Data Library
%       col 9   VW-RF   (added below)
%       col 10  EW-RF   (added below)
%
%   Monthly data spans Jan-1926 thru Dec-2018


%cd(Directory.Data)
%    data=xlsread('NYSE2018.xlsx','b2:h1117');
%    RF=xlsread('NYSE2018.xlsx','n2:n1117');
%cd(Directory.Programs)


%   RF data starts 1926:7, so first 6 cells in spreadsheet are blank.
%   insert NaNs in first 6 rows of RF.
%   These dates are not part of our sample, so not a big deal.

%RF=[nan(6,1);RF];


%   add RF into 8th column of "data"
%data=[data RF];


%   add excess market returns into columns 9+10
%data=[data data(:,4)-data(:,8) data(:,6)-data(:,8)];

%data(:,4:end)=data(:,4:end)*100;    % express returns as percentages


%   ----------------------------------------------------
%   "data" was read from .xlsx in previous code and saved as data.mat


%   "data" is 1116x10 double array
%   Monthly data spanning Jan-1926 thru Dec-2018
%
%       col 1   mthnum ranging from 1:1116
%       col 2   YYYY
%       col 3   MM
%       col 4   VW mkt (inc dividend distributions)
%       col 5   VW mkt (ex. div)
%       col 6   EW mkt (inc dividend distributions)
%       col 7   EW mkt (ex. div)
%       col 8   RF
%       col 9   VW-RF
%       col 10  EW-RF

load data.mat               % already saved in BGJ_Table1.m


%   Full sample spans Apr-1954 (mthnum=340) thru Dec-1986 (mthnum=732)
%   Subperiod1 spans  Apr-1954 (mthnum=340) thru Jul-1970 (mthnum=535)
%   Subperiod2 spans  Aug-1970 (mthnum=536) thru Dec-1986 (mthnum=732)


%%  Full Sample Results

%   First prediction is for 1954:4 (mthnum = 340)
%   Fit regression model over mthnums 304:339.
%   BGJ (p.1179, bot) suggest that they forecast x_t+1 by
%   plugging in r_t+1 "which is known at the end period t".


%   Simply define the "start" and "finish" of the period being investigated.
%   Send them to the subroutine "TradingStrategy" to compile the all-important "signal" structure.


start=340;          % 1954:01
finish=732;         % 1986:12


signal=TradingStrategy(start,finish);


%   "signal" will be an Nx7 array with columns:
%       col 1   mthnum
%       col 2   yyyy
%       col 3   mm
%       col 4   excess market return
%       col 5   RF
%       col 6   0/1 signal for investment in tbill (equities)
%       col 7   excess return on managed portfolio



fprintf('********************************************************\n');
fprintf('Full In-Sample results; VW market first, then EW results\n');
fprintf('********************************************************\n\n');



%  Generate BGJ Table 2 output

fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.vw)-sum(signal.vw(:,6)));
I=signal.vw(:,6)==0 & signal.vw(:,4)<0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.vw(:,6)));
I=signal.vw(:,6)==1 & signal.vw(:,4)>=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));



fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.ew)-sum(signal.ew(:,6)));
I=signal.ew(:,6)==0 & signal.ew(:,4)<0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.ew(:,6)));
I=signal.ew(:,6)==1 & signal.ew(:,4)>=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));



fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.vw(:,7)))
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.vw(:,7)))

y=signal.vw(2:end,7);
ylag=[ones(length(y),1) signal.vw(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));



fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.ew(:,7)));
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.ew(:,7)));

y=signal.ew(2:end,7);
ylag=[ones(length(y),1) signal.ew(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));


clear I t window x y yhat ylag beta


%   "signal" is an Nx7 array with columns:
%       col 1   mthnum
%       col 2   yyyy
%       col 3   mm
%       col 4   excess market return
%       col 5   RF
%       col 6   0/1 signal for investment in tbill (equities)
%       col 7   excess return on managed portfolio


%%  Subperiod 1 Results

%   subperiod 1 spans 1954:4 thru 1970:7 (340 <= mthnum <= 535)
%   First prediction is for 1954:4 (mthnum = 340)
%   Fit model over mthnums 304:339.


start=340;          % 1954:1
finish=535;         % 1970:7

signal=TradingStrategy(start,finish);


fprintf('********************************************************\n');
fprintf('First subperiod in-sample results; VW market first, then EW results\n');
fprintf('********************************************************\n\n');


%  Generate BGJ Table 2 output

fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.vw)-sum(signal.vw(:,6)));
I=signal.vw(:,6)==0 & signal.vw(:,4)<=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.vw(:,6)));
I=signal.vw(:,6)==1 & signal.vw(:,4)>0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));



fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.ew)-sum(signal.ew(:,6)));
I=signal.ew(:,6)==0 & signal.ew(:,4)<=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.ew(:,6)));
I=signal.ew(:,6)==1 & signal.ew(:,4)>0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));



fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.vw(:,7)));
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.vw(:,7)));

y=signal.vw(2:end,7);
ylag=[ones(length(y),1) signal.vw(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));


fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.ew(:,7)));
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.ew(:,7)));

y=signal.ew(2:end,7);
ylag=[ones(length(y),1) signal.ew(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));


clear I t window x y yhat ylag beta


%%  Subperiod 2 Results

%   subperiod 2 spans 1970:8 thru 1986:12 (536 <= mthnum <= 732)
%   First prediction is for 1970:8 (mthnum = 536)
%   Fit model over mthnums 500:535.


start=536;          % 1954:1
finish=732;         % 1970:7

signal=TradingStrategy(start,finish);

fprintf('********************************************************\n');
fprintf('Second subperiod in-sample results; VW market first, then EW results\n');
fprintf('********************************************************\n\n');



%  Generate BGJ Table 2 output

fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.vw)-sum(signal.vw(:,6)));
I=signal.vw(:,6)==0 & signal.vw(:,4)<0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.vw(:,6)));
I=signal.vw(:,6)==1 & signal.vw(:,4)>=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));


fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.ew)-sum(signal.ew(:,6)));
I=signal.ew(:,6)==0 & signal.ew(:,4)<0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.ew(:,6)));
I=signal.ew(:,6)==1 & signal.ew(:,4)>=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));



fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.vw(:,7)));
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.vw(:,7)));

y=signal.vw(2:end,7);
ylag=[ones(length(y),1) signal.vw(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));


fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.ew(:,7)));
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.ew(:,7)));

y=signal.ew(2:end,7);
ylag=[ones(length(y),1) signal.ew(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));


clear I t window x y yhat ylag beta


%%  Update Full Out-of-sample period Results

%   Full update period  spans Jan-1987 (mthnum=733) thru Dec-2018 (mthnum=1116)
%   Update Subperiod1   spans Jan-1987 (mthnum=733) thru Jul-2007 (mthnum=979)
%   Update Subperiod2   spans Aug-2007 (mthnum=980) thru Dec-2018 (mthnum=1116)
%   Combined in-sample + out-sample period spans Apr-1954 (mthnum=340) thru Dec-2018 (mthnum=1116)


start=733;          % 1987:1
finish=1116;        % 2018:12

signal=TradingStrategy(start,finish);


fprintf('********************************************************\n');
fprintf('Full out-of-sample results; VW market first, then EW results\n');
fprintf('********************************************************\n\n');


%  Generate BGJ Table 2 output

fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.vw)-sum(signal.vw(:,6)));
I=signal.vw(:,6)==0 & signal.vw(:,4)<0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.vw(:,6)));
I=signal.vw(:,6)==1 & signal.vw(:,4)>=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));



fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.ew)-sum(signal.ew(:,6)));
I=signal.ew(:,6)==0 & signal.ew(:,4)<0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.ew(:,6)));
I=signal.ew(:,6)==1 & signal.ew(:,4)>=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));



fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.vw(:,7)));
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.vw(:,7)));

y=signal.vw(2:end,7);
ylag=[ones(length(y),1) signal.vw(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));


fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.ew(:,7)));
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.ew(:,7)));

y=signal.ew(2:end,7);
ylag=[ones(length(y),1) signal.ew(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));


clear I t window x y yhat ylag beta


%%  Update Subperiod 1 Results

%   Update subperiod 1 spans 1987:01 thru 2007:07 (733 <= mthnum <= 979)
%   First prediction is for 1987:1 (mthnum = 733)
%   Fit model over mthnums 697:732.


start=733;          % 1987:1
finish=979;         % 2007:7

signal=TradingStrategy(start,finish);

fprintf('********************************************************\n');
fprintf('Subperiod1 out-of-sample results; VW market first, then EW results\n');
fprintf('********************************************************\n\n');



%  Generate BGJ Table 2 output

fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.vw)-sum(signal.vw(:,6)));
I=signal.vw(:,6)==0 & signal.vw(:,4)<=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.vw(:,6)));
I=signal.vw(:,6)==1 & signal.vw(:,4)>0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));



fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.ew)-sum(signal.ew(:,6)));
I=signal.ew(:,6)==0 & signal.ew(:,4)<=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.ew(:,6)));
I=signal.ew(:,6)==1 & signal.ew(:,4)>0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));



fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.vw(:,7)));
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.vw(:,7)));

y=signal.vw(2:end,7);
ylag=[ones(length(y),1) signal.vw(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));


fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.ew(:,7)));
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.ew(:,7)));

y=signal.ew(2:end,7);
ylag=[ones(length(y),1) signal.ew(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));


clear I t window x y yhat ylag beta


%%  Update Subperiod 2 Results

%   Update subperiod 2 spans 2007:08 thru 2018:12 (980 <= mthnum <= 1116)
%   First prediction is for 2007:108 (mthnum = 980)
%   Fit model over mthnums 944:979.


start=980;              % 2007:08
finish=1116;            % 2018:12

signal=TradingStrategy(start,finish);


fprintf('********************************************************\n');
fprintf('Subperiod2 out-of-sample results; VW market first, then EW results\n');
fprintf('********************************************************\n\n');


%  Generate BGJ Table 2 output

fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.vw)-sum(signal.vw(:,6)));
I=signal.vw(:,6)==0 & signal.vw(:,4)<=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.vw(:,6)));
I=signal.vw(:,6)==1 & signal.vw(:,4)>0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));



fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.ew)-sum(signal.ew(:,6)));
I=signal.ew(:,6)==0 & signal.ew(:,4)<=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.ew(:,6)));
I=signal.ew(:,6)==1 & signal.ew(:,4)>0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));



fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.vw(:,7)));
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.vw(:,7)));

y=signal.vw(2:end,7);
ylag=[ones(length(y),1) signal.vw(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));


fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.ew(:,7)));
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.ew(:,7)));

y=signal.ew(2:end,7);
ylag=[ones(length(y),1) signal.ew(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));


clear I t window x y yhat ylag beta



%%  Combined In-sample + Out-Sample period Results

%   Combined sample period spans 1954:4 thru 2018:12 (340 <= mthnum <= 1116)


start=340;          % 1954:04
finish=1116;        % 2018:12

signal=TradingStrategy(start,finish);


fprintf('********************************************************\n');
fprintf('Combined in-sample + out-sample results; VW market first, then EW results\n');
fprintf('********************************************************\n\n');



%  Generate BGJ Table 2 output

fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.vw)-sum(signal.vw(:,6)));
I=signal.vw(:,6)==0 & signal.vw(:,4)<0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.vw(:,6)));
I=signal.vw(:,6)==1 & signal.vw(:,4)>=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));


fprintf('Forecasted down markets\t\t%3.0f\n',length(signal.ew)-sum(signal.ew(:,6)));
I=signal.ew(:,6)==0 & signal.ew(:,4)<0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));

fprintf('Forecasted up markets\t\t%3.0f\n',sum(signal.ew(:,6)));
I=signal.ew(:,6)==1 & signal.ew(:,4)>=0;
fprintf('correct forecasts\t\t\t%3.0f\n\n',sum(I));


fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.vw(:,7)));
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.vw(:,7)));

y=signal.vw(2:end,7);
ylag=[ones(length(y),1) signal.vw(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));


fprintf('Mean monthly excess return\t\t\t%2.4f\n',mean(signal.ew(:,7)));
fprintf('Stdev of monthly excess returns\t\t%2.4f\n',std(signal.ew(:,7)));

y=signal.ew(2:end,7);
ylag=[ones(length(y),1) signal.ew(1:end-1,7)];
beta=(ylag'*ylag)\(ylag'*y);
fprintf('rho(1) of monthly excess returns\t%2.4f\n\n',beta(2));


clear I t window x y yhat ylag beta


%%  save singals.mat
%
%   the 0/1 flag for fixed-income (equities) is utilised for Table 4
%   market-timing tests.


%   "signal" is an 777x7 array with columns:
%       col 1   mthnum
%       col 2   yyyy
%       col 3   mm
%       col 4   excess market return
%       col 5   RF
%       col 6   0/1 signal for investment in tbill (equities)
%       col 7   excess return on managed portfolio


save signals_CombinedSample.mat signal



%%  Tidy Up

clear y x 
toc;
