%   BGJ_Table3.m
%
%   This code does the following:
%       replicates BGJ Table 3 for full in-sample period and two subperiods
%       generates analogous estimates for the out-of-sample Update 
%
%
%   nb: BGJ Table 3 is replicated in Table 2 of OUR paper.
%
%
%   Data are monthly returns to the CRSP "NYSE-only" market indices from WRDS.
%   RF returns are sourced from Ken French's Data Library.
%
%
%   Key takeaways:
%       everything is really close to BGJ Table 3.
%
%
%   This code generates regression estimates for both VW and EW NYSE index.
%   The former is tabulated in our paper; the latter in the appendix.
%
%   This codes estimates regressions with vanilla, HAC/White stderrs using
%   m-files publicly available from https://www.spatial-econometrics.com/
%
%
%   PG: 28 Nov-2018
%   PG:  4 Feb-2019:    updated with data thru to Dec-2018
%
%%  Preliminaries


clear;
clc;
tic;


Directory.Data='G:\active\papers\CFR\Accompanying Files\data';
Directory.Programs='G:\active\papers\CFR\Accompanying Files\programs';


%%  Load Data
%
%   Either load data from NYSE2018.xlsx, OR
%   if "BGJ_Table1.m" has been run, the data will already reside in a mat-file.
%
%
%   "NYSE2018.xlsx" is a spreadhseet containg a WRDS download of 
%   monthly returns as follows:
%       
%       col     YYYYMMDD (not used)
%       col 1   mthnum ranging from 1:1116
%       col 2   YYYY
%       col 3   MM
%       col 4   NYSE-only VW mkt (inc dividend distributions)
%       col 5   NYSE-only VW mkt (ex. div)
%       col 6   NYSE-only EW mkt (inc dividend distributions)
%       col 7   NYSE-only EW mkt (ex. div)
%       col     "totval" (not used)
%       col     "totcnt" (not used)
%       col     "usdval" (not used)
%       col     "usdcnt" (not used)
%
%       col 8   RF from Ken French Data Library
%       col 9   VW-RF   (added below)
%       col 10  EW-RF   (added below)
%
%   Monthly data spans Jan-1926 thru Dec-2018


%cd(Directory.Data)
%    data=xlsread('NYSE2018.xlsx','b2:h1117');
%    RF=xlsread('NYSE2018.xlsx','n2:n1117');
%cd(Directory.Programs)


%   RF data starts 1926:7, so first 6 cells in spreadsheet are blank.
%   insert NaNs in first 6 rows of RF.
%   These dates are not part of our sample, so not a big deal.

%RF=[nan(6,1);RF];


%   add RF into 8th column of "data"
%data=[data RF];


%   add excess market returns into columns 9+10
%data=[data data(:,4)-data(:,8) data(:,6)-data(:,8)];

%data(:,4:end)=data(:,4:end)*100;    % express returns as percentages


%   ----------------------------------------------------
%   "data" was read from .xlsx in previous code and saved as data.mat


%   "data" is 1116x10 double array
%   Monthly data spanning Jan-1926 thru Dec-2018
%
%       col 1   mthnum ranging from 1:1116
%       col 2   YYYY
%       col 3   MM
%       col 4   VW mkt (inc dividend distributions)
%       col 5   VW mkt (ex. div)
%       col 6   EW mkt (inc dividend distributions)
%       col 7   EW mkt (ex. div)
%       col 8   RF
%       col 9   VW-RF
%       col 10  EW-RF

load data.mat               % already saved in BGJ_Table1.m


%%  Replicate BGJ Table 3 Predictive Regressions

%   Full sample spans Apr-1954 (mthnum=340) thru Dec-1986 (mthnum=732)
%   Subperiod1 spans  Apr-1954 (mthnum=340) thru Jul-1970 (mthnum=535)
%   Subperiod2 spans  Aug-1970 (mthnum=536) thru Dec-1986 (mthnum=732)


vnames=['y        ';
        'intercept';
        'slope    '];


fprintf('Full in-sample regressions: VW Market\n')
fprintf('Panel A:\n')

y=data(340:732,9);                  % VW mkt in excess of RF
x=data(340:732,8);                  % RF is contemporaneous (but known one month earlier)
x=[ones(length(x),1) x];

%results=nwest(y,x,20);             % use this if want HAC stderrs
results=hwhite(y,x);                % BGJ (p.1181) suggests Table 3 Panel A uses White stderr
prt(results,vnames);



fprintf('Full in-sample regressions: VW Market\n')
fprintf('Panel B:\n\n')

y=results.resid.^2;                 % squared error terms
x=data(340:732,8);                  % contemporaneous RF
x=[ones(length(y),1) x];

                                    % BGJ report both HAC and White t-stats
results=nwest(y,x,20);              % (round brackets) use HAC stderr
prt(results,vnames);
results=hwhite(y,x);                % [square brackets] use White stderr
prt(results,vnames);



fprintf('Full in-sample regressions: EW Market\n')
fprintf('Panel A:\n')


y=data(340:732,10);                 % EW mkt in excess of RF
x=data(340:732,8);                  % RF
x=[ones(length(x),1) x];

%results=nwest(y,x,20);
results=hwhite(y,x);
prt(results,vnames);


fprintf('Full in-sample regressions: EW Market\n')
fprintf('Panel B:\n\n')

y=results.resid.^2;                 % squared error terms
x=data(340:732,8);                  % RF
x=[ones(length(y),1) x];

results=nwest(y,x,20);
prt(results,vnames);
results=hwhite(y,x);
prt(results,vnames);


%%  In-sample Subperiod 1
%
%   Subperiod1 spans  Apr-1954 (mthnum=340) thru Jul-1970 (mthnum=535)


fprintf('Subperiod 1 in-sample regressions: VW Market\n')
fprintf('Panel A:\n')

y=data(340:535,9);                  % VW mkt in excess of RF
x=data(340:535,8);                  % RF contemporaneous
x=[ones(length(x),1) x];

results=hwhite(y,x);                % BGJ (p.1181) suggests Table 3 Panel A uses White stderr
prt(results,vnames);


fprintf('Subperiod 1 in-regressions: VW Market\n')
fprintf('Panel B:\n\n')

y=results.resid.^2;                 % squared error terms
x=data(340:535,8);                  % contemporaneous RF
x=[ones(length(y),1) x];

results=nwest(y,x,14);              % (round brackets] are HAC stderr
prt(results,vnames);
results=hwhite(y,x);                % [square brackets] are White stderr
prt(results,vnames);



fprintf('Subperiod 1 in-sample regressions: EW Market\n')
fprintf('Panel A:\n\n')

y=data(340:535,10);                  % EW mkt in excess of RF
x=data(340:535,8);                   % RF contemporaneous
x=[ones(length(x),1) x];

%results=nwest(y,x,14);
results=hwhite(y,x);
prt(results,vnames);


fprintf('Subperiod 1 in-sample regressions: EW Market\n')
fprintf('Panel B:\n\n')

y=results.resid.^2;                 % squared error terms
x=data(340:535,8);                  % contemporaneous RF
x=[ones(length(y),1) x];

results=nwest(y,x,14);
prt(results,vnames);
results=hwhite(y,x);
prt(results,vnames);


%%  In-sample Subperiod 2
%
%   Subperiod2 spans  Aug-1970 (mthnum=536) thru Dec-1986 (mthnum=732)


fprintf('Subperiod 2 in-sample regressions: VW Market\n')
fprintf('Panel A:\n')

y=data(536:732,9);                  % VW mkt in excess of RF
x=data(536:732,8);                  % RF contemporaneous
x=[ones(length(x),1) x];

%results=nwest(y,x,14);
results=hwhite(y,x);                % BGJ (p.1181) suggests Table 3 Panel A uses White stderr
prt(results,vnames);


fprintf('Subperiod 2 in-sample regressions: VW Market\n')
fprintf('Panel B:\n\n')

y=results.resid.^2;                 % squared error terms
x=data(536:732,8);                  % contemporaneous RF
x=[ones(length(y),1) x];

results=nwest(y,x,14);              % [square brackets] are HAC stderr
prt(results,vnames);
results=hwhite(y,x);               % (round brackets) are ??? stderr
prt(results,vnames);



fprintf('Subperiod 2 in-sample regressions: EW Market\n')
fprintf('Panel A:\n')

y=data(536:732,10);                 % EW mkt in excess of RF
x=data(536:732,8);                  % RF contemporaneous
x=[ones(length(x),1) x];

%results=nwest(y,x,14);
results=hwhite(y,x);
prt(results,vnames);


fprintf('Subperiod 2 in-sample regressions: EW Market\n')
fprintf('Panel B:\n')

y=results.resid.^2;                 % squared error terms
x=data(536:732,8);                  % contemporaneous RF
x=[ones(length(y),1) x];

results=nwest(y,x,14);
prt(results,vnames);
results=hwhite(y,x);
prt(results,vnames);


%%  Update Out-of-Sample Regressions

%   Full update period  spans Jan-1987 (mthnum=733) thru Dec-2018 (mthnum=1116)
%   Update Subperiod1   spans Jan-1987 (mthnum=733) thru Jul-2007 (mthnum=979)
%   Update Subperiod2   spans Aug-2007 (mthnum=980) thru Dec-2018 (mthnum=1116)
%   Combined in-sample + out-sample period spans Apr-1954 (mthnum=340) thru Dec-2018 (mthnum=1116)



fprintf('Update out-of-sample regressions: VW Market\n')
fprintf('Panel A:\n')

y=data(733:1116,9);                  % VW mkt in excess of RF
x=data(733:1116,8);                  % RF contemporaneous
x=[ones(length(x),1) x];

%results=nwest(y,x,20);
results=hwhite(y,x);                % BGJ (p.1181) suggests Table 3 Panel A uses White stderr
prt(results,vnames);



fprintf('Update out-of-sample regressions: VW Market\n')
fprintf('Panel B:\n\n')

y=results.resid.^2;                 % squared error terms
x=data(733:1116,8);                  % contemporaneous RF
x=[ones(length(y),1) x];

results=nwest(y,x,20);              % (round brackets) are HAC stderr
prt(results,vnames);
results=hwhite(y,x);               % [square brackets] are White stderr
prt(results,vnames);



fprintf('Update out-of-sample regressions: EW Market\n')
fprintf('Panel A:\n')


y=data(733:1116,10);                 % EW mkt in excess of RF
x=data(733:1116,8);                  % RF contemporaneous
x=[ones(length(x),1) x];

%results=nwest(y,x,20);
results=hwhite(y,x);
prt(results,vnames);


fprintf('Update out-of-sample regressions: EW Market\n')
fprintf('Panel B:\n\n')

y=results.resid.^2;                 % squared error terms
x=data(733:1116,8);                  % contemporaneous RF
x=[ones(length(y),1) x];

results=nwest(y,x,20);
prt(results,vnames);
results=hwhite(y,x);
prt(results,vnames);


%   -------------------------------------------------------------
fprintf('Update subperiod1 regressions: VW Market\n')
fprintf('Panel A:\n')


y=data(733:979,9);                  % VW mkt in excess of RF
x=data(733:979,8);                  % RF contemporaneous
x=[ones(length(x),1) x];

%results=nwest(y,x,14);
results=hwhite(y,x);                % BGJ (p.1181) suggests Table 3 Panel A uses White stderr
prt(results,vnames);



fprintf('Update subperiod1 regressions: VW Market\n')
fprintf('Panel B:\n\n')

y=results.resid.^2;                 % squared error terms
x=data(733:924,8);                  % contemporaneous RF
x=data(733:979,8);                  % contemporaneous RF
x=[ones(length(y),1) x];

results=nwest(y,x,14);              % (round brackets) are HAC stderr
prt(results,vnames);
results=hwhite(y,x);               % [square brackets] are White stderr
prt(results,vnames);



fprintf('Update subperiod1 regressions: EW Market\n')
fprintf('Panel A:\n')

y=data(733:979,10);                 % EW mkt in excess of RF
x=data(733:979,8);                  % RF contemporaneous
x=[ones(length(x),1) x];

%results=nwest(y,x,14);
results=hwhite(y,x);                % BGJ (p.1181) suggests Table 3 Panel A uses White stderr
prt(results,vnames);



fprintf('Update subperiod1 regressions: EW Market\n')
fprintf('Panel B:\n\n')

y=results.resid.^2;                 % squared error terms
x=data(733:979,8);                  % contemporaneous RF
x=[ones(length(y),1) x];

results=nwest(y,x,14);              % (round brackets) are HAC stderr
prt(results,vnames);
results=hwhite(y,x);                % [square brackets] are White stderr
prt(results,vnames);


%   -------------------------------------------------------------
fprintf('Update subperiod2 regressions: VW Market\n')
fprintf('Panel A:\n')

y=data(980:1116,9);                 % VW mkt in excess of RF
x=data(980:1116,8);                 % RF contemporaneous
x=[ones(length(x),1) x];

%results=nwest(y,x,14);
results=hwhite(y,x);                % BGJ (p.1181) suggests Table 3 Panel A uses White stderr
prt(results,vnames);



fprintf('Update subperiod2 regressions: VW Market\n')
fprintf('Panel B:\n\n')

y=results.resid.^2;                 % squared error terms
x=data(980:1116,8);                 % contemporaneous RF
x=[ones(length(y),1) x];

results=nwest(y,x,14);              % (round brackets) are HAC stderr
prt(results,vnames);
results=hwhite(y,x);               % [square brackets] are White stderr
prt(results,vnames);



fprintf('Update subperiod2 regressions: EW Market\n')
fprintf('Panel A:\n')

y=data(980:1116,10);                % EW mkt in excess of RF
x=data(980:1116,8);                 % RF contemporaneous
x=[ones(length(x),1) x];

%results=nwest(y,x,14);
results=hwhite(y,x);                % BGJ (p.1181) suggests Table 3 Panel A uses White stderr
prt(results,vnames);



fprintf('Update subperiod2 regressions: EW Market\n')
fprintf('Panel B:\n\n')

y=results.resid.^2;                 % squared error terms
x=data(980:1116,8);                 % contemporaneous RF
x=[ones(length(y),1) x];

results=nwest(y,x,14);              % (round brackets) are HAC stderr
prt(results,vnames);
results=hwhite(y,x);               % [square brackets] are White stderr
prt(results,vnames);


% -----------------------------------------------------------------------

fprintf('Combined In-sample + Out-sample regressions: VW Market\n')
fprintf('Panel A:\n')

y=data(340:1116,9);                  % VW mkt in excess of RF
x=data(340:1116,8);                  % RF contemporaneous
x=[ones(length(x),1) x];

%results=nwest(y,x,20);
results=hwhite(y,x);                % BGJ (p.1181) suggests Table 3 Panel A uses White stderr
prt(results,vnames);



fprintf('Combined In-sample + Out-sample regressions: VW Market\n')
fprintf('Panel B:\n\n')

y=results.resid.^2;                 % squared error terms
x=data(340:1116,8);                  % contemporaneous RF
x=[ones(length(y),1) x];

results=nwest(y,x,20);              % (round brackets) are HAC stderr
prt(results,vnames);
results=hwhite(y,x);               % [square brackets] are White stderr
prt(results,vnames);



fprintf('Combined In-sample + Out-sample regressions: EW Market\n')
fprintf('Panel A:\n')


y=data(340:1116,10);                 % EW mkt in excess of RF
x=data(340:1116,8);                  % RF contemporaneous
x=[ones(length(x),1) x];

%results=nwest(y,x,20);
results=hwhite(y,x);
prt(results,vnames);


fprintf('Combined In-sample + Out-sample regressions: EW Market\n')
fprintf('Panel B:\n\n')

y=results.resid.^2;                 % squared error terms
x=data(340:1116,8);                 % contemporaneous RF
x=[ones(length(y),1) x];

results=nwest(y,x,20);
prt(results,vnames);
results=hwhite(y,x);
prt(results,vnames);



%%  Tidy Up

clear y x

toc;









