%   BGJ_Table4_EW.m
%
%   Replicate BGJ Table 4: for EW mkt ndx (tabulated in appendix)
%
%
%   Data are monthly returns to the CRSP "NYSE-only" market indices from WRDS.
%   RF returns are sourced from Ken French's Data Library.
%
%
%   PG:  1 Dec-2018
%   PG:  4 Feb-2019:    updated with data thru to Dec-2018
%   PG: 22 Feb-2018:    modifying the code to generate resutls for EW mkt ndx


%%  Preliminaries

clear;
clc;
tic;


Directory.Data='G:\active\papers\CFR\Accompanying Files\data';
Directory.Programs='G:\active\papers\CFR\Accompanying Files\programs';


%%  Load Data
%
%   Either load data from NYSE2018.xlsx, OR
%   if "BGJ_Table1.m" has been run, the data will already reside in a mat-file.
%
%
%   "NYSE2018.xlsx" is a spreadhseet containg a WRDS download of 
%   monthly returns as follows:
%       
%       col     YYYYMMDD (not used)
%       col 1   mthnum ranging from 1:1116
%       col 2   YYYY
%       col 3   MM
%       col 4   NYSE-only VW mkt (inc dividend distributions)
%       col 5   NYSE-only VW mkt (ex. div)
%       col 6   NYSE-only EW mkt (inc dividend distributions)
%       col 7   NYSE-only EW mkt (ex. div)
%       col     "totval" (not used)
%       col     "totcnt" (not used)
%       col     "usdval" (not used)
%       col     "usdcnt" (not used)
%
%       col 8   RF from Ken French Data Library
%       col 9   VW-RF   (added below)
%       col 10  EW-RF   (added below)
%
%   Monthly data spans Jan-1926 thru Dec-2018


%cd(Directory.Data)
%    data=xlsread('NYSE2018.xlsx','b2:h1117');
%    RF=xlsread('NYSE2018.xlsx','n2:n1117');
%cd(Directory.Programs)


%   RF data starts 1926:7, so first 6 cells in spreadsheet are blank.
%   insert NaNs in first 6 rows of RF.
%   These dates are not part of our sample, so not a big deal.

%RF=[nan(6,1);RF];


%   add RF into 8th column of "data"
%data=[data RF];


%   add excess market returns into columns 9+10
%data=[data data(:,4)-data(:,8) data(:,6)-data(:,8)];

%data(:,4:end)=data(:,4:end)*100;    % express returns as percentages


%   ----------------------------------------------------
%   "data" was read from .xlsx in previous code and saved as data.mat


%   "data" is 1116x10 double array
%   Monthly data spanning Jan-1926 thru Dec-2018
%
%       col 1   mthnum ranging from 1:1116
%       col 2   YYYY
%       col 3   MM
%       col 4   VW mkt (inc dividend distributions)
%       col 5   VW mkt (ex. div)
%       col 6   EW mkt (inc dividend distributions)
%       col 7   EW mkt (ex. div)
%       col 8   RF
%       col 9   VW-RF
%       col 10  EW-RF

load data.mat               % already saved in BGJ_Table1.m


%   Full sample spans Apr-1954 (mthnum=340) thru Dec-1986 (mthnum=732)
%   Subperiod1 spans  Apr-1954 (mthnum=340) thru Jul-1970 (mthnum=535)
%   Subperiod2 spans  Aug-1970 (mthnum=536) thru Dec-1986 (mthnum=732)



%%  Full Sample Results

%   First prediction is for 1954:4 (mthnum = 340)
%   Fit model over mthnums 304:339.
%   BGJ (p.1179, bot) suggest that they forecast x_t+1 by
%   plugging in r_t+1 "which is known at the end period t".


%   "signal" is an Nx7 array with columns:
%       col 1   mthnum
%       col 2   yyyy
%       col 3   mm
%       col 4   excess market return
%       col 5   RF
%       col 6   0/1 signal for investment in tbill (equities)
%       col 7   excess return on managed portfolio


load signals_CombinedSample



%   ***  important to note ***

%   "signal" is a structure with 777 rows.
%   BGJ in-sample period comprises the first 393 months of signals.
%   in code below, I am referencing the "signal" number, not the "mthnum"
%   as in previous m-files.


%%  Replicate BGJ Table 4 market-timing tests


fprintf('Full sample regressions: EW Market\n')
fprintf('BGJ Table 4 Replication, Panel A:\n')


%   The CM test is BGJ (1989, eqn 3).
%   It regress month-t excess mkt ret on a dummy variable taking the value
%   of unity when the predictive model forecasts an up market.
%
%   intercept a_0 captures average excess mkt ret when model predicts down mkt.
%   slope a_1 captures the incremental excess mkt ret when model predicts up mkt.
%   CM test the null that a_1=0.

y=signal.ew(1:393,4);           % excess EW market return
x=signal.ew(1:393,6);           % 0 (1) indicator for forecasted down (up) market
x=[ones(length(y),1) x];

%results=ols(y,x);
results=nwest(y,x,20);
%results=hwhite(y,x);
prt(results);


fprintf('BGJ Table 4 Replication, Panel B:\n')

%   BGJ (1989) Table 4 Panel B tests whether the variance of excess mkt
%   rets differs between forecasted up/down markets.
%   They regress the squared error term from the previous regn on the 0/1 dummy var.
%   The slope coefft is significantly negative, suggesting excess rets are
%   more volatile during forecasted down mkts.

v2=results.resid.^2;            % square of residuals from Cumby-Modest regression
results=nwest(v2,x,20);         % "x" is the same as above; (round brackets) are HAC stderr
prt(results);
results=hwhite(v2,x);           % [square brackets] are White stderr
prt(results);


fprintf('BGJ Table 4 Replication, Panel C:\n')

%   BGJ (1989) Table 4 Panel C tests whether the short rate can predict
%   times when the excess mkt ret is more likely to be positive. 
%   BGJ Eqn (4) tests  for a positive slope on c_1.

I=signal.ew(1:393,4)>0;             % ystar equals unity when actual excess mkt return is positive
ystar=double(I);
results=nwest(ystar,x,20);      % "x" is the same as above
prt(results);


fprintf('BGJ Table 4 Replication, Panel D:\n')

%   BGJ (1989) Table 4 Panel D implements (a version of) HM's (1981) 'value at margin'.
%   See BGJ (1989) eqn (5).

results=nwest(x(:,2),[ones(length(ystar),1) ystar],20);
prt(results)
results=hwhite(x(:,2),[ones(length(ystar),1) ystar]);       % can only match BGJ t-stats using White
prt(results)


%%  BGJ Table 4 Subperiod 1


fprintf('Subperiod 1 regressions: EW Market\n')
fprintf('BGJ Table 4 Replication, Panel A:\n')


y=signal.ew(1:196,4);           % excess EW market return
x=signal.ew(1:196,6);           % 0 (1) indicator for forecasted down (up) market
x=[ones(length(y),1) x];

results=nwest(y,x,14);
%results=hwhite(y,x);
prt(results);


fprintf('BGJ Table 4 Replication, Panel B:\n')

v2=results.resid.^2;            % square of residuals from Cumby-Modest regression
results=nwest(v2,x,14);         % "x" is the same as above; (round brackets) are HAC stderr
prt(results);
results=hwhite(v2,x);           % [square brackets] are White stderr
prt(results);


fprintf('BGJ Table 4 Replication, Panel C:\n')

I=signal.ew(1:196,4)>0;         % ystar equals unity when actual excess mkt return is positive
ystar=double(I);
results=nwest(ystar,x,14);      % "x" is the same as above
prt(results);


fprintf('BGJ Table 4 Replication, Panel D:\n')

results=nwest(x(:,2),[ones(length(ystar),1) ystar],14);
prt(results)
results=hwhite(x(:,2),[ones(length(ystar),1) ystar]);       % can only match BGJ t-stats using White
prt(results)


%%  BGJ Table 4 Subperiod 2


fprintf('Subperiod 2 regressions: EW Market\n')
fprintf('BGJ Table 4 Replication, Panel A:\n')


y=signal.ew(197:393,4);           % excess VW market return
x=signal.ew(197:393,6);           % 0 (1) indicator for forecasted down (up) market
x=[ones(length(y),1) x];

results=nwest(y,x,14);
%results=hwhite(y,x);
prt(results);


fprintf('BGJ Table 4 Replication, Panel B:\n')

v2=results.resid.^2;            % square of residuals from Cumby-Modest regression
results=nwest(v2,x,14);         % "x" is the same as above; (round brackets) are HAC stderr
prt(results);
results=hwhite(v2,x);           % [square brackets] are White stderr
prt(results);


fprintf('BGJ Table 4 Replication, Panel C:\n')

I=signal.ew(197:393,4)>0;       % ystar equals unity when actual excess mkt return is positive
ystar=double(I);
results=nwest(ystar,x,14);      % "x" is the same as above
prt(results);


fprintf('BGJ Table 4 Replication, Panel D:\n')

results=nwest(x(:,2),[ones(length(ystar),1) ystar],14);
prt(results)
results=hwhite(x(:,2),[ones(length(ystar),1) ystar]);       % can only match BGJ t-stats using White
prt(results)


%%  Update Full out-of-sample period

%   Full update period  spans Jan-1987 (mthnum=733) thru Dec-2018 (mthnum=1116)
%   Update Subperiod1   spans Jan-1987 (mthnum=733) thru Dec-2002 (mthnum=924)
%   Update Subperiod2   spans Jan-2003 (mthnum=925) thru Dec-2018 (mthnum=1116)
%   Combined in-sample + out-sample period spans Apr-1954 (mthnum=340) thru Dec-2018 (mthnum=1116)



fprintf('Full Out-of-sample Period regressions: EW Market\n')
fprintf('BGJ Table 4 Update, Panel A:\n')


y=signal.ew(394:777,4);         % excess VW market return
x=signal.ew(394:777,6);         % 0 (1) indicator for forecasted down (up) market
x=[ones(length(y),1) x];

results=nwest(y,x,20);
%results=hwhite(y,x);
prt(results);


fprintf('BGJ Table 4 Update, Panel B:\n')

v2=results.resid.^2;            % square of residuals from Cumby-Modest regression
results=nwest(v2,x,20);         % "x" is the same as above; (round brackets) are HAC stderr
prt(results);
results=hwhite(v2,x);           % [square brackets] are White stderr
prt(results);


fprintf('BGJ Table 4 Update, Panel C:\n')

I=signal.ew(394:777,4)>0;      % ystar equals unity when actual excess mkt return is positive
ystar=double(I);
results=nwest(ystar,x,20);      % "x" is the same as above
prt(results);


fprintf('BGJ Table 4 Update, Panel D:\n')

results=nwest(x(:,2),[ones(length(ystar),1) ystar],20);
prt(results)
results=hwhite(x(:,2),[ones(length(ystar),1) ystar]);       % can only match BGJ t-stats using White
prt(results)


%%  Update Subperiod 1


fprintf('Subperiod 1 regressions: EW Market\n')
fprintf('BGJ Table 4 Replication, Panel A:\n')


y=signal.ew(394:640,4);           % excess EW market return
x=signal.ew(394:640,6);           % 0 (1) indicator for forecasted down (up) market


x=[ones(length(y),1) x];

results=nwest(y,x,14);
%results=hwhite(y,x);
prt(results);


fprintf('BGJ Table 4 Replication, Panel B:\n')

v2=results.resid.^2;            % square of residuals from Cumby-Modest regression
results=nwest(v2,x,14);         % "x" is the same as above; (round brackets) are HAC stderr
prt(results);
results=hwhite(v2,x);           % [square brackets] are White stderr
prt(results);


fprintf('BGJ Table 4 Replication, Panel C:\n')

I=signal.ew(394:640,4)>0;         % ystar equals unity when actual excess mkt return is positive
ystar=double(I);
results=nwest(ystar,x,14);      % "x" is the same as above
prt(results);


fprintf('BGJ Table 4 Replication, Panel D:\n')

results=nwest(x(:,2),[ones(length(ystar),1) ystar],14);
prt(results)
results=hwhite(x(:,2),[ones(length(ystar),1) ystar]);       % can only match BGJ t-stats using White
prt(results)


%%  Update Subperiod 2


fprintf('Subperiod 2 regressions: EW Market\n')
fprintf('BGJ Table 4 Replication, Panel A:\n')


y=signal.ew(641:777,4);           % excess EW market return
x=signal.ew(641:777,6);           % 0 (1) indicator for forecasted down (up) market
x=[ones(length(y),1) x];

results=nwest(y,x,14);
%results=hwhite(y,x);
prt(results);


fprintf('BGJ Table 4 Replication, Panel B:\n')

v2=results.resid.^2;            % square of residuals from Cumby-Modest regression
results=nwest(v2,x,14);         % "x" is the same as above; (round brackets) are HAC stderr
prt(results);
results=hwhite(v2,x);           % [square brackets] are White stderr
prt(results);


fprintf('BGJ Table 4 Replication, Panel C:\n')

I=signal.ew(641:777,4)>0;         % ystar equals unity when actual excess mkt return is positive
ystar=double(I);
results=nwest(ystar,x,14);      % "x" is the same as above
prt(results);


fprintf('BGJ Table 4 Replication, Panel D:\n')

results=nwest(x(:,2),[ones(length(ystar),1) ystar],14);
prt(results)
results=hwhite(x(:,2),[ones(length(ystar),1) ystar]);       % can only match BGJ t-stats using White
prt(results)


%%  Combined In-sample + Out-sample period


fprintf('Combined In-sample + Out-sample Period regressions: EW Market\n')
fprintf('BGJ Table 4 Update, Panel A:\n')


y=signal.ew(1:777,4);         % excess EW market return
x=signal.ew(1:777,6);         % 0 (1) indicator for forecasted down (up) market
x=[ones(length(y),1) x];

results=nwest(y,x,20);
%results=hwhite(y,x);
prt(results);


fprintf('BGJ Table 4 Update, Panel B:\n')

v2=results.resid.^2;            % square of residuals from Cumby-Modest regression
results=nwest(v2,x,20);         % "x" is the same as above; (round brackets) are HAC stderr
prt(results);
results=hwhite(v2,x);           % [square brackets] are White stderr
prt(results);


fprintf('BGJ Table 4 Update, Panel C:\n')

I=signal.ew(1:777,4)>0;      % ystar equals unity when actual excess mkt return is positive
ystar=double(I);
results=nwest(ystar,x,20);      % "x" is the same as above
prt(results);


fprintf('BGJ Table 4 Update, Panel D:\n')

results=nwest(x(:,2),[ones(length(ystar),1) ystar],20);
prt(results)
results=hwhite(x(:,2),[ones(length(ystar),1) ystar]);       % can only match BGJ t-stats using White
prt(results)


%%  Tidy Up


toc;









