%   PlaceboData_AllKeyResults.m
%
%
%   This m-file generates the key results regarding return predictability
%   for a placebo dataset ('PlaceboData.xlsx'), which is a randomized subset
%   of data from an international market.
%
%   An interested reader can run this code on the placebo data, compare 
%   their results to the printout of results provided, thus ensuring that
%   they are running the code correctly.
%
%   The printout of results for placebo data will also be useful if a
%   reader is tranlsating our matlab code to a different software language.
%
%
%   note: this codes estimates regressions with HAC or White stderrs using
%   m-files publicly available from https://www.spatial-econometrics.com/
%
%
%   TH: 7 Apr-2019


%%  Preliminaries


clc;
tic;

global data



%   User must modify the "Directory" structure below to point matlab to
%   where the data/code is saved.

Directory.Programs='G:\active\papers\CFR\Accompanying Files\programs';
Directory.Data='G:\active\papers\CFR\Accompanying Files\data';


%%  Load placebo data and organise as required by subsequent matlab functions.


display('Note: The sample is a randomized subset of data on a random market.');


cd(Directory.Data)
    data=xlsread('PlaceboData.xlsx','A2:E469');
cd(Directory.Programs)


data=[data data(:,4)-data(:,5)];        % create Rm - Rf in 6th column


%   The "data" array must have the following format, which is expected in processing below:
%   "data" is a Nx6 array  with columns:
%       mthID, YYYY, MM, RM, RF , RM-RF


%%  Generate key estimates for placebo dataset


%   "junk" holds relevant data for full in-sample period

junk=data(:,[4 5 6]);            % RM, RF, RM-RF

output=[mean(junk)' std(junk)'];


disp('***********************************************')
disp('BGJ Table 1: Excess Return on Buy-Hold Market')
disp('***********************************************')

fprintf('\tMean\tStdDev\n')
fprintf('\t%2.4f\t%2.4f\n\n',output(3,[1 2]));

clear junk output


%%  Calculate key stats for managed portfolio (i.e., trading strategy)


start=37;                       % first forecast uses previous 36 months data
finish=length(data(:,1));       

signal=TradingStrategy_placebo(start,finish);


%   "signal" is an Nx7 array with columns:
%       col 1   mthnum
%       col 2   yyyy
%       col 3   mm
%       col 4   excess market return
%       col 5   RF
%       col 6   0/1 signal for investment in tbill (equities)
%       col 7   excess return on managed portfolio


%  Generate BGJ Table 2 output

disp('***************************************************')
disp('BGJ Table 2: Excess Returns on Trading Strategy *')
disp('***************************************************')
fprintf('\tMean\tStdev\n');
fprintf('\t%2.4f\t%2.4f\n\n',[mean(signal(:,7)) std(signal(:,7))]);


%% Generate Key output for BGJ Table 3


disp('***********************************')
disp('BGJ Table 3: full sample regression')
disp('***********************************')


y=data(:,6);                  % mkt return in excess of RF
x=data(:,5);                  % RF contemporaneous
x=[ones(length(x),1) x];

results=hwhite(y,x);                % BGJ (p.1181) suggests Table 3 Panel A uses White stderr

fprintf('beta1\t\t%2.4f\n',results.beta(2))
fprintf('tstat\t\t%2.4f\n',results.tstat(2))
fprintf('Rsqr\t\t%2.4f\n\n\n',results.rsqr)


%%  Replicate BGJ Table 4 market-timing tests


disp('********************************')
disp('BGJ Table 4: market-timing tests')
disp('********************************')

fprintf('BGJ Table 4 Replication, Panel A:\n')


%   The CM test is BGJ (1989, eqn 3).
%   It regress month-t excess mkt ret on a dummy variable taking the value
%   of unity when the predictive model forecasts an up market.
%
%   intercept a_0 captures average excess mkt ret when model predicts down mkt.
%   slope a_1 captures the incremental excess mkt ret when model predicts up mkt.
%   CM test the null that a_1=0.

y=signal(:,4);              % excess market returns
x=signal(:,6);              % 0 (1) indicator for forecasted down (up) market
x=[ones(length(y),1) x];
results=nwest(y,x,20);

fprintf('alpha1\t\t%2.4f\n',results.beta(2))
fprintf('tstat\t\t%2.4f\n\n\n',results.tstat(2))


fprintf('BGJ Table 4 Replication, Panel B:\n')

%   BGJ (1989) Table 4 Panel B tests whether the variance of excess mkt
%   rets differs between forecasted up/down markets.
%   They regress the squared error term from the previous regn on the 0/1 dummy var.
%   The slope coefft is significantly negative, suggesting excess rets are
%   more volatile during forecasted down mkts.

v2=results.resid.^2;            % square of residuals from Cumby-Modest regression
results=nwest(v2,x,20);         % "x" is the same as above; (round brackets) are HAC stderr

fprintf('b1\t\t\t%2.4f\n',results.beta(2))
fprintf('tstat\t\t%2.4f\n\n\n',results.tstat(2))


fprintf('BGJ Table 4 Replication, Panel C:\n')

%   BGJ (1989) Table 4 Panel C tests whether the short rate can predict
%   times when the excess mkt ret is more likely to be positive. 
%   BGJ Eqn (4) tests  for a positive slope on c_1.

I=signal(:,4)>0;                % ystar equals unity when actual excess mkt return is positive
ystar=double(I);
results=nwest(ystar,x,20);      % "x" is the same as above

fprintf('c1\t\t\t%2.4f\n',results.beta(2))
fprintf('tstat\t\t%2.4f\n\n\n',results.tstat(2))



fprintf('BGJ Table 4 Replication, Panel D:\n')

%   BGJ (1989) Table 4 Panel D implements (a version of) HM's (1981) 'value at margin'.
%   See BGJ (1989) eqn (5).

results=nwest(x(:,2),[ones(length(ystar),1) ystar],20);
fprintf('alpha1\t\t%2.4f\n',results.beta(2))
fprintf('tstat\t\t%2.4f\n\n\n',results.tstat(2))


%   construct Henriksson and Merton Value-at-Margin

format long
alpha1=results.beta(2)

RF=data(:,5);
RM=data(:,4);

StrikePrice = exp(nanmean(log(1+RF/100)));
MeanRf = (nanmean(log(1+RF/100)));
Volatility = std(log(1+RM/100));
T=1;
number_months = length(RF);


d1=(log(1/StrikePrice)+(MeanRf +0.5*Volatility^2)*T)/(Volatility*sqrt(T));
d2=d1-Volatility*sqrt(T);
Nd1=normcdf(d1,0,1);
Nd2=normcdf(d2,0,1);
BS=1*Nd1-StrikePrice*Nd2*exp(-MeanRf*T);


%   given that the table reports alpha1 to 2 dps, I will round it here so
%   that readers can easily arrive at the same VaM.
%   Rounding to 2 dps only makes a negligible difference to VaM.


VaM= 12*round(alpha1,2)*BS*100



